"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchAppListForSelectedSystem = exports.formatAppChoices = exports.extractAppData = exports.getYUIDetails = void 0;
const constants_1 = require("../utils/constants");
const prompt_state_1 = require("./prompt-state");
const i18n_1 = require("../utils/i18n");
const logger_1 = __importDefault(require("../utils/logger"));
/**
 * Returns the details for the YUI prompt.
 *
 * @returns step details
 */
function getYUIDetails() {
    return [
        {
            name: constants_1.generatorTitle,
            description: constants_1.generatorDescription
        }
    ];
}
exports.getYUIDetails = getYUIDetails;
/**
 * Returns the prompt details for the selected application.
 *
 * @param {AppItem} app - The application item to extract details from.
 * @returns {{ name: string; value: AppInfo }} The extracted details including name and value.
 */
const extractAppData = (app) => {
    // cast to string because TypeScript doesn't automatically know at the point that these fields are defined
    // after filtering out invalid apps.
    const id = app['sap.app/id'];
    const title = app['sap.app/title'];
    const description = (app['sap.app/description'] ?? '');
    const repoName = app.repoName;
    const url = app.url;
    return {
        name: id,
        value: {
            appId: id,
            title,
            description,
            repoName,
            url
        }
    };
};
exports.extractAppData = extractAppData;
/**
 * Formats the application list into selectable choices.
 *
 * @param {AppIndex} appList - List of applications retrieved from the system.
 * @returns {Array<{ name: string; value: AppInfo }>} The formatted choices for selection.
 */
const formatAppChoices = (appList) => {
    return appList
        .filter((app) => {
        const hasRequiredFields = app['sap.app/id'] && app['sap.app/title'] && app['repoName'] && app['url'];
        if (!hasRequiredFields) {
            logger_1.default.logger?.error((0, i18n_1.t)('error.requiredFieldsMissing', { app: JSON.stringify(app) }));
        }
        return hasRequiredFields;
    })
        .map((app) => (0, exports.extractAppData)(app));
};
exports.formatAppChoices = formatAppChoices;
/**
 * Fetches a list of deployed applications from the ABAP repository.
 *
 * @param {AbapServiceProvider} provider - The ABAP service provider.
 * @param {string} appId - Application ID to filter the list.
 * @returns {Promise<AppIndex>} A list of applications filtered by source template.
 */
async function getAppList(provider, appId) {
    try {
        const searchParams = appId
            ? {
                ...constants_1.appListSearchParams,
                'sap.app/id': appId
            }
            : constants_1.appListSearchParams;
        return await provider.getAppIndex().search(searchParams, constants_1.appListResultFields);
    }
    catch (error) {
        logger_1.default.logger?.error((0, i18n_1.t)('error.applicationListFetchError', { error: error.message }));
        return [];
    }
}
/**
 * Fetches the application list for the selected system.
 *
 * @param {AbapServiceProvider} serviceProvider - The ABAP service provider.
 * @param {string} appId - Application ID to be downloaded.
 * @returns {Promise<AppIndex>} A list of applications filtered by source template.
 */
async function fetchAppListForSelectedSystem(serviceProvider, appId) {
    if (serviceProvider) {
        prompt_state_1.PromptState.systemSelection = {
            connectedSystem: { serviceProvider }
        };
        return await getAppList(serviceProvider, appId);
    }
    return [];
}
exports.fetchAppListForSelectedSystem = fetchAppListForSelectedSystem;
//# sourceMappingURL=prompt-helpers.js.map