"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPrompts = void 0;
const odata_service_inquirer_1 = require("@sap-ux/odata-service-inquirer");
const types_1 = require("../app/types");
const i18n_1 = require("../utils/i18n");
const project_input_validator_1 = require("@sap-ux/project-input-validator");
const prompt_state_1 = require("./prompt-state");
const prompt_helpers_1 = require("./prompt-helpers");
const validators_1 = require("../utils/validators");
/**
 * Gets the target folder selection prompt.
 *
 * @param {string} [appRootPath] - The application root path.
 * @param {string} appId - The application ID.
 * @returns {FileBrowserQuestion<RepoAppDownloadAnswers>} The target folder prompt configuration.
 */
const getTargetFolderPrompt = (appRootPath, appId) => {
    return {
        type: 'input',
        name: types_1.PromptNames.targetFolder,
        message: (0, i18n_1.t)('prompts.targetPath.message'),
        guiType: 'folder-browser',
        when: (answers) => {
            // Display the prompt if appId is provided. This occurs when the generator is invoked
            // as part of the quick deployment process from ADT.
            if (appId) {
                return true;
            }
            // If appId is not provided, check if the user has selected an app.
            // If an app is selected, display the prompt accordingly.
            return Boolean(answers?.selectedApp?.appId);
        },
        guiOptions: {
            applyDefaultWhenDirty: true,
            mandatory: true,
            breadcrumb: (0, i18n_1.t)('prompts.targetPath.breadcrumb')
        },
        validate: async (target, answers) => {
            const selectedAppId = answers.selectedApp?.appId ?? appId;
            return await (0, project_input_validator_1.validateFioriAppTargetFolder)(target, selectedAppId, true);
        },
        default: () => appRootPath
    };
};
/**
 * Retrieves prompts for selecting a system, app list, and target folder where the app will be generated.
 *
 * @param {string} [appRootPath] - The root path of the application.
 * @param {QuickDeployedAppConfig} [quickDeployedAppConfig] - The quick deployed app configuration.
 * @returns {Promise<RepoAppDownloadQuestions[]>} A list of prompts for user interaction.
 */
async function getPrompts(appRootPath, quickDeployedAppConfig) {
    try {
        prompt_state_1.PromptState.reset();
        const systemQuestions = await (0, odata_service_inquirer_1.getSystemSelectionQuestions)({
            serviceSelection: { hide: true },
            systemSelection: { defaultChoice: quickDeployedAppConfig?.serviceProviderInfo?.name }
        }, false);
        let appList = [];
        const appSelectionPrompt = [
            {
                when: async (answers) => {
                    if (answers[types_1.PromptNames.systemSelection]) {
                        appList = await (0, prompt_helpers_1.fetchAppListForSelectedSystem)(systemQuestions.answers.connectedSystem?.serviceProvider, quickDeployedAppConfig?.appId);
                    }
                    return !!systemQuestions.answers.connectedSystem?.serviceProvider;
                },
                type: 'list',
                name: types_1.PromptNames.selectedApp,
                default: () => (quickDeployedAppConfig?.appId ? 0 : undefined),
                guiOptions: {
                    mandatory: !!appList.length,
                    breadcrumb: (0, i18n_1.t)('prompts.appSelection.breadcrumb')
                },
                message: (0, i18n_1.t)('prompts.appSelection.message'),
                choices: () => (appList.length ? (0, prompt_helpers_1.formatAppChoices)(appList) : []),
                validate: async (answers) => (0, validators_1.validateAppSelection)(answers, appList, quickDeployedAppConfig)
            }
        ];
        const targetFolderPrompts = getTargetFolderPrompt(appRootPath, quickDeployedAppConfig?.appId);
        return [...systemQuestions.prompts, ...appSelectionPrompt, targetFolderPrompts];
    }
    catch (error) {
        throw new Error(`Failed to generate prompts: ${error.message}`);
    }
}
exports.getPrompts = getPrompts;
//# sourceMappingURL=prompts.js.map